

clear all
set more off
set mem 1g
set matsize 800


* Import Raw Data
import delimited "RawData_JEPS.csv", encoding(ISO-8859-1) clear


* Fill in Data for Groups
foreach x in dga dgb  {
bysort country eday group (`x'): replace `x' = `x'[1] if dgrole=="C"
}
foreach x in riga rigb  {
bysort country eday group (`x'): replace `x' = `x'[1] if rigrole=="C"
}

* Create Group IDs
egen groupid=concat(country eday group)
egen grouptag=tag(groupid)

* Replace Sanction Measure (Reduction for A ---> Paid by C)
replace dgcsanction=dgcsanction/3
replace rigcsanction=rigcsanction/3
replace rigcsanctiona=rigcsanctiona/3
replace rigcsanctionb=rigcsanctionb/3


* Identify Ethnic Minorities
gen ethmin=(vtribe~=tribe) 

* Change Treatment for Ethnic Minorities (Luo in Kuria villages, Kuria in Luo villages)
recode dgtreatment (1=4) (2=3) (3=2) (4=1) if dgrole=="A" & ethmin==1 & tribe~="Other"
recode dgtreatment (1=2) (2=1) (3=4) (4=3) if dgrole=="C" & ethmin==1 & tribe~="Other"
recode rigtreatment (1=2) (2=1) (3=4) (4=3) if rigrole=="C" & ethmin==1 & tribe~="Other"

* Drop Non-Luo/Non-Kuria Participants 
gen ethoth=(tribe=="Other")
drop if ethoth==1

* Drop Participants Who Fail Comprehension Test
drop if test<0.75

* Generate New Variables
gen DG_AB_coethnic=(dgtreatment==1|dgtreatment==2)
gen DG_AC_coethnic=(dgtreatment==1|dgtreatment==3)
gen DG_BC_coethnic=(dgtreatment==1|dgtreatment==4)
gen RIG_AB_coethnic=(rigtreatment==1|rigtreatment==2)
gen RIG_AC_coethnic=(rigtreatment==1|rigtreatment==3)
gen RIG_BC_coethnic=(rigtreatment==1|rigtreatment==4)
tab dgtreatment, gen(dg)
	gen ABC=dg1 
	gen AB=dg2
	gen AC=dg3 
	gen BC=dg4 
tab rigtreatment, gen(rig)
	gen rABC=rig1 
	gen rAB=rig2
	gen rAC=rig3 
	gen rBC=rig4 
gen male=(gender=="male")
replace male=. if gender=="[blank]" | gender==""
recode identity1 (2=0), gen(natsim_self)
recode identity2 (1=0)(2=1), gen(natsim)
recode identity3 (2=0), gen(ethsim_self)
gen natvseth=identity4
recode natvseth (1 2 3=1)(4 5=0), gen(national)
replace village="Nyasoro" if village=="Nyasoko"
tab village, gen(vil)
gen luo=(tribe=="Luo")
gen anger=imagine 
recode retribution (5=1)(4=2)(3=3)(2=4)(1=5) // higher numbers, more support for retribution

* Code Spiteful Behavior (RIG Reduction That Increased Inequality)
gen spitea=(rigcsanctiona~=0 & riga<6)
gen spiteb=(rigcsanctionb~=0 & rigb<6)
gen spite=(spitea==1 | spiteb==1)
gen spite_coeth=(spitea==1 & RIG_AC_coethnic==1)
replace spite_coeth=1 if spiteb==1 & RIG_BC_coethnic==1

*Lable Variables and Values
lab var male "Male"
lab var education "Education Level"
lab var income "Income Level"
lab var age "Age"
lab var dga "Amount Kept (A)"
lab var DG_BC_coethnic "BC Coethnic (ABC \& BC)"
lab var DG_AC_coethnic "AC Coethnic (ABC \& AC)"
lab var riga "Amount Allocated (A)"
lab var rigb "Amount Allocated (B)"
lab def treatments 1 "ABC" 2 "AB" 3 "AC" 4 "BC"
lab val dgtreatment treatments
lab val rigtreatment treatments
lab var rABC "ABC"
lab var rAB "AB"
lab var rAC "AC"
lab var rBC "BC"


save "FinalData_JEPS.dta", replace






